/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.linkis.common.exception;

public class LinkisRetryException extends LinkisRuntimeException {
  LinkisRetryException(int errCode, String desc, String ip, int port, String serviceKind) {
    super(errCode, desc, ip, port, serviceKind);
  }

  public LinkisRetryException(int errCode, String desc) {
    super(errCode, desc);
  }

  @Override
  public ExceptionLevel getLevel() {
    return ExceptionLevel.RETRY;
  }
}
